@@ -250,27 +250,31 @@ class OppParser(ConfigParser):
         for f in filenames:
             self.ini_root_path = os.path.dirname(os.path.abspath(f))
             file_content = self.get_file_content_recursively(f)
-            file_contents.append(file_content)
+            file_contents.append("".join(file_content))
 
         return file_contents
 
-    def get_lines_include(self, filename):
+    def get_lines_include(self, input: str|List[str]):
 
-        line_nrs = list()
+        line_nrs = {}
 
-        with open(filename) as f:
-            lines = f.readlines()
+        if isinstance(input, str):
+            with open(input) as f:
+                lines = f.readlines()
+        else:
+            lines = input
 
-        for index in range(len(lines)):
-            if lines[index].__contains__("include"):
-                line_nrs.append(index)
+        for idx, line in enumerate(lines):
+            if line.strip().startswith("include "):
+                _inc_path = line.strip().split(" ")[-1]
+                line_nrs[idx] = _inc_path
 
         return line_nrs
 
     def has_file_include(self, filename):
 
         line_nrs = self.get_lines_include(filename)
-        if len(line_nrs) == 0:
+        if  line_nrs == {}:
             return False
         else:
             return True
@@ -296,41 +300,34 @@ class OppParser(ConfigParser):
         f = os.path.join(os.path.abspath(f_))
         logging.info(f"Generate absolute path: {f_} ")
 
-        if os.path.isfile(f):
-            logging.info("Set current dir to. \n")
-        else:
-            f = os.path.abspath(os.path.join(self.current_dir, f_))
-
-            logging.info("No file absolute file path found. \n")
-            logging.info(f"Try: {f_} ")
-
-        self.current_dir = os.path.dirname(f)
+        current_dir = os.path.dirname(f)
 
         with open(f) as f_:
-            file_content = f_.read()
+            file_content = f_.readlines()
 
-        lines = self.get_lines_include(f)
+        lines: List[str] = self.get_lines_include(f)
 
-        for l in lines:
-            inc_file_name, replace_string = self.get_inc_file_name(f, l)
+        line_offset = 0
+        for line, path in lines.items():
+            
+            if not os.path.isabs(path):
+                path = os.path.join(current_dir, path)
+            
+            print(f"read file {path}")
 
-            print(f"{f} has file include: {self.has_file_include(f)} ({inc_file_name})")
-
-            if self.has_file_include(f):
-                file_content = file_content.replace(
-                    replace_string, self.get_file_content_recursively(inc_file_name)
-                )
-                self.current_dir = self.ini_root_path
+            lines_to_include = self.get_file_content_recursively(path)
+            _start = line + line_offset
+            file_content[_start] = f"###include {file_content[_start]}\n"
+            _lines = []
+            _lines.extend(file_content[0:_start+1])
+            _lines.extend(lines_to_include)
+            _lines.append(f"{file_content[_start].strip()} END\n")
+            _lines.extend(file_content[_start+1:])
+            file_content = _lines
+            line_offset = line_offset + len(lines_to_include) + 1
 
         return file_content
 
-    def get_inc_file_name(self, filename, index):
-
-        with open(filename) as f:
-            lines = f.readlines()
-
-        inc_file = lines[index].split(" ")[-1].split("\n")[0]
-        return inc_file, lines[index]
 
 
 class OppConfigType():
